@@ -8,6 +8,7 @@ from typecasts import Typecasts, casts
 from platonic.const import const
 
 # Max number of SQS messages receivable by single API call.
+# Also, max number of SQS messages deletable by single API call.
 MAX_NUMBER_OF_MESSAGES = 10
 
 # Message in its raw form must be shorter than this.
@@ -25,3 +26,10 @@ class SQSMixin:
     typecasts: Typecasts = field(default_factory=const(casts))
     internal_type: type = field(default=str)
     client: SQSClient = field(default_factory=partial(boto3.client, 'sqs'))
+    batch_size: int = field(default=MAX_NUMBER_OF_MESSAGES, metadata={
+        '__doc__': (
+            f'Max number of SQS messages to process within one API call. '
+            f'Default is {MAX_NUMBER_OF_MESSAGES}. Exceeding the max value '
+            f'will cause validation errors from AWS.'
+        ),
+    })
